import { createWebHistory , createRouter } from 'vue-router'

import Layout from '../layout/index.vue'
import HomeView from '../views/home/index.vue'
import PlanningHome from '../views/planning/home.vue'
import HouseWorkbench from '../views/house/workbench/index.vue'
import Consignor from '../views/house/workbench/consignor.vue'
import Conditions from '../views/house/workbench/conditions.vue'
import GuarantyResult from '../views/house/workbench/guarantyResult.vue'
import FolderChild from '../views/house/folder/child.vue'
import FolderParent from '../views/house/folder/parent.vue'
import Folder from '../views/house/folder/index.vue'
import AssetsFolder from '@/views/assets/folder/index.vue'
import AssetsFolderParent from '@/views/assets/folder/parent.vue'
import AssetsFolderChild from '@/views/assets/folder/child.vue'
import AssetsTmpl from '@/views/assets/template/index.vue'
import AssetsTmplMange from '@/views/assets/template/mange.vue'
import AssetsCreateCalculateTmpl from '@/views/assets/template/createCalculate.vue'
import AssetsCreateReportTmpl from '@/views/assets/template/createReport.vue'
import AssetsCalculateWorkbench from '@/views/assets/workbench/calculate/index.vue'
import AssetsCalculateBaseInfo from '@/views/assets/workbench/calculate/baseInfo.vue'
import AssetsCalculateImportInfo from '@/views/assets/workbench/calculate/importInfo.vue'
import AssetsCalculateEqptBaseInfo from '@/views/assets/workbench/calculate/eqptBaseInfo.vue'
import AssetsReportWorkbench from '@/views/assets/workbench/report/index.vue'
import AssetsReportBaseInfo from '@/views/assets/workbench/report/baseInfo.vue'
import AssetsReportEqptBaseInfo from '@/views/assets/workbench/report/eqptBaseInfo.vue'

const routes = [
  {
    path: '/',
    redirect: '/home/index'
  },
  {
    path: '/home',
    redirect: '/home/index'
  },
  {
    path: '/home/house',
    redirect: '/home/house/parent'
  },
  {
    path: '/home/houseWorkbench',
    redirect: '/home/house/parent'
  },
  {
    path: '/home/assets',
    redirect: '/home/assets/parent'
  },
  {
    path: '/home/assets/template',
    redirect: '/home/assets/template/mange'
  },
  {
    path: '/home/assets/workbench/calculate',
    redirect: '/home/assets/folder'
  },
  {
    path: '/home/assets/workbench/report',
    redirect: '/home/assets/folder'
  },
  {
    path: '/home',
    component: Layout,
    name: 'home',
    meta: {
      title: '首页'
    },
    children: [
      {
        path: 'index',
        component: HomeView,
        name: 'homeIndex',
      },
      {
        path: 'planning',
        component: PlanningHome,
        name: 'planningIndex',
        meta: {
          title: '土地工作台'
        },
      },
      {
        path: 'house',
        component: Folder,
        name: 'folder',
        meta: {
          title: '房地产工作台'
        },
        children: [
          {
            path: 'parent',
            component: FolderParent,
            name: 'FolderParent',
            meta: {
              title: '项目'
            },
          },
          {
            path: 'folder',
            component: FolderChild,
            name: 'folderChild',
            meta: {
              title: '文件夹'
            },
          }

        ]
      },
      {
        path: 'houseWorkbench',
        component: HouseWorkbench,
        name: 'houseWorkbench',
        meta: {
          title: '房地产项目'
        },
        children: [
          {
            path: 'consignor',
            component: Consignor,
            name: 'consignor',
            meta: {
              title: '委托人函'
            },
          },
          {
            path: 'conditions',
            component: Conditions,
            name: 'conditions',
            meta: {
              title: '假设限制条件及使用说明'
            },
          },
          {
            path: 'guarantyResult',
            component: GuarantyResult,
            name: 'guarantyResult',
            meta: {
              title: '房地产抵押估价结果报告'
            },
          },
        ]

      },
      {
        path: 'assets',
        component: AssetsFolder,
        name: 'assetsFolder',
        meta: {
          title: '资产工作台'
        },
        children: [
          {
            path: 'parent',
            component: AssetsFolderParent,
            name: 'assetsFolderParent',
            meta: {
              title: '项目'
            },
          },
          {
            path: 'folder',
            component: AssetsFolderChild,
            name: 'assetsFolderChild',
            meta: {
              title: '文件夹'
            },
          },      
          {
            path: 'template',
            component: AssetsTmpl,
            name: 'assetsTmpl',
            meta: {
              title: '模板管理'
            },
            children: [
              {
                path: 'mange',
                component: AssetsTmplMange,
                name: 'assetsTmplMange',
                // meta: {
                //   title: '模板列表'
                // },
              },
              {
                path: 'create/calculate',
                component: AssetsCreateCalculateTmpl,
                name: 'assetsCreateCalculateTmpl',
                meta: {
                  title: '创建测算表模板'
                },
              },
              {
                path: 'create/report',
                component: AssetsCreateReportTmpl,
                name: 'assetsCreateReportTmpl',
                meta: {
                  title: '创建报告模板'
                },
              }
            ]
          },
          {
            path: 'workbench/calculate',
            component: AssetsCalculateWorkbench,
            name: 'assetsCalculateWorkbench',
            meta: {
              title: '文件夹'
            },
            children: [
              {
                path: 'baseInfo',
                component: AssetsCalculateBaseInfo,
                name: 'assetsCalculateBaseInfo',
                meta: {
                  title: '测算表基本信息'
                },
              },
              {
                path: 'importInfo',
                component: AssetsCalculateImportInfo,
                name: 'assetsCalculateimportInfo',
                meta: {
                  title: '完善测算表信息'
                },
              },
              {
                path: 'eqptBaseInfo',
                component: AssetsCalculateEqptBaseInfo,
                name: 'assetsCalculateEqptBaseInfo',
                meta: {
                  title: '生成测算表'
                },
              },
            ]
          },
          {
            path: 'workbench/report',
            component: AssetsReportWorkbench,
            name: 'assetsReportWorkbench',
            meta: {
              title: '文件夹'
            },
            children: [
              {
                path: 'baseInfo',
                component: AssetsReportBaseInfo,
                name: 'assetsReportBaseInfo',
                meta: {
                  title: '报告基本信息'
                },
              },
              {
                path: 'eqptBaseInfo',
                component: AssetsReportEqptBaseInfo,
                name: 'assetsReportEqptBaseInfo',
                meta: {
                  title: '生成报告'
                },
              },
            ]
          }
        ],
      }
    ],

  },
  {
    path: '/showDoc',
    name: 'doc',
    component: () => import('../components/PageOffice/index.vue')
  }
]

const router = createRouter({
  history: createWebHistory('/prod/'),
  routes,
})

export default router